@@ -48,7 +48,7 @@ TEXTDOMAINDIR=/usr/share/locale
 TEXTDOMAIN=unplugdrive
 
 title=$"Unplug USB device"
-version="0.93a"
+version="0.93b"
 txt_version=$"Version "$version                    #text string for translation
 
 icon_taskbar="/usr/share/icons/numix-square-antix/48x48/devices/usbpendrive_unmount.png"
@@ -233,6 +233,13 @@ get_devices() {
     [ ! -z "$DEVICES" ] && echo "$DEVICES"
 }
 
+get_block_devices() {
+	local DEVICE="$@"
+	[ -z "$DEVICE" ] && return 0
+	local BLOCK_DEVICE="$(lsblk -no pkname $DEVICE)"
+	[ ! -z "$BLOCK_DEVICE" ] && echo "$BLOCK_DEVICE"
+}
+
 get_mount_points() {
     local MOUNT_SOURCE="${1}"
     local MOUNT_POINTS="$(findmnt -lno TARGET "$MOUNT_SOURCE")"
@@ -305,7 +312,7 @@ close_encrypt_error() {
 # Using find in /dev/disk/by-id/ to figure out if a block device is USB or not.
 # Then it checks if it has mounted points. If both pass, it saves the block name.
 stage_1() {
-    local BLOCK_LIST BLOCK_PATH
+    local BLOCK_LIST PMOUNT_LIST BLOCK_PATH
     
     echo_debug "\n1.) Searching for USB block devices\n-----------------------------------\n"
     
@@ -314,6 +321,8 @@ stage_1() {
     # block_name_array (each element is a unique device block, found to be USB and have mount points).
     echo_debug "1.1) Check if any USB device is mounted"
     BLOCK_LIST="$(lsblk -d -rno NAME)"
+    PMOUNT_LIST="$(pmount | grep /dev/ | cut -d" " -f1 | sort -u )"
+    [ ! -z "$PMOUNT_LIST" ] && PMOUNT_LIST="$(get_block_devices $PMOUNT_LIST | sort -u)"
     
     while read -r block; do
         # If block device empty, jump to next device block
@@ -324,6 +333,8 @@ stage_1() {
             echo_debug "$block is an USB device."
         elif is_sd "$block"; then
             echo_debug "$block is a SD device."
+        elif [ ! -z "$PMOUNT_LIST" ] && [ $(echo "$PMOUNT_LIST" | grep -xc "$block") -gt 0 ];  then
+            echo_debug "$block is listed in pmount."
         else
             continue
         fi
